@@ -34,6 +34,9 @@ MONASCA_LOG_API_BASE_URI=${MONASCA_LOG_API_SERVICE_PROTOCOL}://${MONASCA_LOG_API
 MONASCA_LOG_API_URI_V2=${MONASCA_LOG_API_BASE_URI}/v2.0
 MONASCA_LOG_API_URI_V3=${MONASCA_LOG_API_BASE_URI}/v3.0
 
+# wsgit bits
+MONASCA_LOG_API_USE_MOD_WSGI=$(trueorfalse False MONASCA_LOG_API_USE_MOD_WSGI)
+
 # configuration bits
 LOG_PERSISTER_DIR=$DEST/monasca-log-persister
 LOG_TRANSFORMER_DIR=$DEST/monasca-log-transformer
@@ -52,11 +55,15 @@ LOGSTASH_DIR=$DEST/logstash
 
 PLUGIN_FILES=$MONASCA_LOG_API_DIR/devstack/files
 
+# Files inside this directory will be visible in gates log
+GATE_CONFIGURATION_DIR=/etc/monasca-log-api
+
 # TOP_LEVEL functions called from devstack coordinator
 ###############################################################################
 function pre_install {
     install_elk
     install_node_nvm
+    install_gate_config_holder
 }
 
 function install_monasca_log {
@@ -75,6 +82,24 @@ function install_elk {
     install_kibana
 }
 
+function install_gate_config_holder {
+    sudo install -d -o $STACK_USER $GATE_CONFIGURATION_DIR
+}
+
+function install_monasca_common {
+    if use_library_from_git "monasca-common"; then
+        git_clone_by_name "monasca-common"
+        setup_dev_lib "monasca-common"
+    fi
+}
+
+function install_monasca_statsd {
+    if use_library_from_git "monasca-statsd"; then
+        git_clone_by_name "monasca-statsd"
+        setup_dev_lib "monasca-statsd"
+    fi
+}
+
 function configure_monasca_log {
     configure_kafka
     configure_elasticsearch
@@ -95,7 +120,7 @@ function init_monasca_log {
 
 function stop_monasca_log {
     stop_process "monasca-log-agent" || true
-    stop_process "monasca-log-api" || true
+    stop_monasca_log_api
     stop_process "monasca-log-metrics" || true
     stop_process "monasca-log-persister" || true
     stop_process "monasca-log-transformer" || true
@@ -122,6 +147,7 @@ function clean_monasca_log {
     clean_elasticsearch
     clean_logstash
     clean_node_nvm
+    clean_gate_config_holder
 }
 ###############################################################################
 
@@ -131,16 +157,19 @@ function install_monasca-log-api {
     git_clone $MONASCA_LOG_API_REPO $MONASCA_LOG_API_DIR $MONASCA_LOG_API_BRANCH
     setup_develop $MONASCA_LOG_API_DIR
 
-    pip_install gunicorn
-    pip_install_gr python-memcached
-
-    if use_library_from_git "monasca-common"; then
-        git_clone_by_name "monasca-common"
-        setup_dev_lib "monasca-common"
+    if [ "$MONASCA_LOG_API_USE_MOD_WSGI" == "False" ]; then
+        pip_install gunicorn
     fi
-    if use_library_from_git "monasca-statsd"; then
-        git_clone_by_name "monasca-statsd"
-        setup_dev_lib "monasca-statsd"
+
+    install_keystonemiddleware
+    install_monasca_common
+    install_monasca_statsd
+
+    if [ "$MONASCA_LOG_API_USE_MOD_WSGI" == "True" ]; then
+        install_apache_wsgi
+        if is_ssl_enabled_service "monasca-log-api"; then
+            enable_mod_ssl
+        fi
     fi
 }
 
@@ -152,6 +181,9 @@ function configure_monasca_log_api {
         sudo install -d -o $STACK_USER $MONASCA_LOG_API_CONF_DIR
         create_log_api_cache_dir
 
+        # ensure fresh installation of configuration files
+        rm -rf $MONASCA_LOG_API_CONF $MONASCA_LOG_API_PASTE_INI $MONASCA_LOG_API_LOGGING_CONF
+
         if [[ "$MONASCA_LOG_API_CONF_DIR" != "$MONASCA_LOG_API_DIR/etc/monasca" ]]; then
             install -m 600 $MONASCA_LOG_API_DIR/etc/monasca/log-api-config.conf $MONASCA_LOG_API_CONF
             install -m 600 $MONASCA_LOG_API_DIR/etc/monasca/log-api-config.ini $MONASCA_LOG_API_PASTE_INI
@@ -165,19 +197,10 @@ function configure_monasca_log_api {
         iniset "$MONASCA_LOG_API_CONF" kafka_healthcheck kafka_url $KAFKA_SERVICE_HOST:$KAFKA_SERVICE_PORT
 
         # configure keystone middleware
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken auth_url $KEYSTONE_AUTH_URI
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken auth_uri $KEYSTONE_AUTH_URI
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken identity_uri $KEYSTONE_SERVICE_URI
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken admin_user "admin"
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken admin_password $ADMIN_PASSWORD
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken admin_tenant_name "admin"
-
-        # certs
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken cafile $SSL_BUNDLE_FILE
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken signing_dir $MONASCA_LOG_API_CACHE_DIR
-
-        # memcached
-        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken memcached_servers $SERVICE_HOST:11211
+        configure_auth_token_middleware "$MONASCA_LOG_API_CONF" "admin" $MONASCA_LOG_API_CACHE_DIR
+        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken region_name $REGION_NAME
+        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken project_name "admin"
+        iniset "$MONASCA_LOG_API_CONF" keystone_authtoken password $ADMIN_PASSWORD
 
         # insecure
         if is_service_enabled tls-proxy; then
@@ -188,9 +211,58 @@ function configure_monasca_log_api {
         iniset "$MONASCA_LOG_API_PASTE_INI" server:main host $MONASCA_LOG_API_SERVICE_HOST
         iniset "$MONASCA_LOG_API_PASTE_INI" server:main port $MONASCA_LOG_API_SERVICE_PORT
         iniset "$MONASCA_LOG_API_PASTE_INI" server:main chdir $MONASCA_LOG_API_DIR
+        iniset "$MONASCA_LOG_API_PASTE_INI" server:main workers $API_WORKERS
+
+        # WSGI
+        if [ "$MONASCA_LOG_API_USE_MOD_WSGI" == "True" ]; then
+            configure_monasca_log_api_wsgi
+        fi
+
+        # link configuration for the gate
+        ln -sf $MONASCA_LOG_API_CONF $GATE_CONFIGURATION_DIR
+        ln -sf $MONASCA_LOG_API_PASTE_INI $GATE_CONFIGURATION_DIR
+        ln -sf $MONASCA_LOG_API_LOGGING_CONF $GATE_CONFIGURATION_DIR
+
     fi
 }
 
+function configure_monasca_log_api_wsgi {
+    sudo install -d $MONASCA_LOG_API_WSGI_DIR
+
+    local monasca_log_api_apache_conf
+    monasca_log_api_apache_conf=$(apache_site_config_for monasca-log-api)
+
+    local monasca_log_api_ssl=""
+    local monasca_log_api_certfile=""
+    local monasca_log_api_keyfile=""
+    local monasca_log_api_api_port=$MONASCA_LOG_API_SERVICE_PORT
+    local venv_path=""
+
+    if is_ssl_enabled_service monasca_log_api; then
+        monasca_log_api_ssl="SSLEngine On"
+        monasca_log_api_certfile="SSLCertificateFile $MONASCA_LOG_API_SSL_CERT"
+        monasca_log_api_keyfile="SSLCertificateKeyFile $MONASCA_LOG_API_SSL_KEY"
+    fi
+    if [[ ${USE_VENV} = True ]]; then
+        venv_path="python-path=${PROJECT_VENV["monasca_log_api"]}/lib/$(python_version)/site-packages"
+    fi
+
+    # copy proxy vhost and wsgi helper files
+    sudo cp $MONASCA_LOG_API_DIR/monasca_log_api/wsgi/monasca_log_api.py $MONASCA_LOG_API_WSGI_DIR/monasca_log_api
+    sudo cp $PLUGIN_FILES/apache-log-api.template $monasca_log_api_apache_conf
+    sudo sed -e "
+        s|%PUBLICPORT%|$monasca_log_api_api_port|g;
+        s|%APACHE_NAME%|$APACHE_NAME|g;
+        s|%PUBLICWSGI%|$MONASCA_LOG_API_WSGI_DIR/monasca_log_api|g;
+        s|%SSLENGINE%|$monasca_log_api_ssl|g;
+        s|%SSLCERTFILE%|$monasca_log_api_certfile|g;
+        s|%SSLKEYFILE%|$monasca_log_api_keyfile|g;
+        s|%USER%|$STACK_USER|g;
+        s|%VIRTUALENV%|$venv_path|g
+        s|%APIWORKERS%|$API_WORKERS|g
+    " -i $monasca_log_api_apache_conf
+}
+
 function create_log_api_cache_dir {
     sudo install -m 700 -d -o $STACK_USER $MONASCA_LOG_API_CACHE_DIR
 }
@@ -206,15 +278,61 @@ function clean_monasca_log_api {
         sudo rm -rf $MONASCA_LOG_API_CONF_DIR || true
 
         sudo rm -rf $MONASCA_LOG_API_DIR || true
+
+        if [ "$MONASCA_LOG_API_USE_MOD_WSGI" == "True" ]; then
+            clean_monasca_log_api_wsgi
+        fi
     fi
 }
 
+function clean_monasca_log_api_wsgi {
+    sudo rm -f $MONASCA_LOG_API_WSGI_DIR/*
+    sudo rm -f $(apache_site_config_for monasca-log-api)
+}
+
 function start_monasca_log_api {
     if is_service_enabled monasca-log-api; then
         echo_summary "Starting monasca-log-api"
-        local gunicorn="$MONASCA_LOG_API_BIN_DIR/gunicorn"
+
+        local service_port=$MONASCA_LOG_API_SERVICE_PORT
+        local service_protocol=$MONASCA_LOG_API_SERVICE_PROTOCOL
+        if is_service_enabled tls-proxy; then
+            service_port=$MONASCA_LOG_API_SERVICE_PORT_INT
+            service_protocol="http"
+        fi
+
         restart_service memcached
-        run_process "monasca-log-api" "$gunicorn -n monasca-log-api -k eventlet --paste $MONASCA_LOG_API_PASTE_INI"
+
+        local enabled_site_file
+        enabled_site_file=$(apache_site_config_for monasca-log-api)
+        if [ -f ${enabled_site_file} ] && [ "$MONASCA_LOG_API_USE_MOD_WSGI" == "True" ]; then
+            enable_apache_site monasca-log-api
+            restart_apache_server
+            tail_log monasca-log-api /var/log/$APACHE_NAME/monasca-log-api.log
+        else
+            local gunicorn="$MONASCA_LOG_API_BIN_DIR/gunicorn"
+            run_process "monasca-log-api" "$gunicorn -n monasca-log-api -k eventlet --paste $MONASCA_LOG_API_PASTE_INI"
+        fi
+
+        echo "Waiting for monasca-log-api to start..."
+        if ! wait_for_service $SERVICE_TIMEOUT $service_protocol://$SERVICE_HOST:$service_port; then
+            die $LINENO "monasca-log-api did not start"
+        fi
+
+        if is_service_enabled tls-proxy; then
+            start_tls_proxy monasca-log-api '*' $MONASCA_LOG_API_SERVICE_PORT $MONASCA_LOG_API_SERVICE_HOST $MONASCA_LOG_API_SERVICE_PORT_INT
+        fi
+    fi
+}
+
+function stop_monasca_log_api {
+    if is_service_enabled monasca-log-api; then
+        if [ "$MONASCA_LOG_API_USE_MOD_WSGI" == "True" ]; then
+            disable_apache_site monasca-log-api
+            restart_apache_server
+        else
+            stop_process "monasca-log-api" || true
+        fi
     fi
 }
 
@@ -282,6 +400,8 @@ function configure_elasticsearch {
             s|%ES_DATA_DIR%|$ELASTICSEARCH_DATA_DIR|g;
             s|%ES_LOG_DIR%|$ELASTICSEARCH_LOG_DIR|g;
         " -i $ELASTICSEARCH_CFG_DIR/elasticsearch.yml
+
+        ln -sf $ELASTICSEARCH_CFG_DIR/elasticsearch.yml $GATE_CONFIGURATION_DIR/elasticsearch.yml
     fi
 }
 
@@ -339,11 +459,10 @@ function configure_kibana {
             s|%KIBANA_SERVER_BASE_PATH%|$KIBANA_SERVER_BASE_PATH|g;
             s|%ES_SERVICE_BIND_HOST%|$ES_SERVICE_BIND_HOST|g;
             s|%ES_SERVICE_BIND_PORT%|$ES_SERVICE_BIND_PORT|g;
-            s|%KIBANA_LOG_DIR%|$KIBANA_LOG_DIR|g;
-            s|%KEYSTONE_AUTH_PORT%|$KEYSTONE_AUTH_PORT|g;
-            s|%KEYSTONE_AUTH_HOST%|$KEYSTONE_AUTH_HOST|g;
-            s|%KEYSTONE_AUTH_PROTOCOL%|$KEYSTONE_AUTH_PROTOCOL|g;
+            s|%KEYSTONE_AUTH_URI%|$KEYSTONE_AUTH_URI|g;
         " -i $KIBANA_CFG_DIR/kibana.yml
+
+        ln -sf $KIBANA_CFG_DIR/kibana.yml $GATE_CONFIGURATION_DIR/kibana.yml
     fi
 }
 
@@ -367,7 +486,6 @@ function clean_kibana {
 
         sudo rm -rf $KIBANA_DIR || true
         sudo rm -rf $FILES/kibana-${KIBANA_VERSION}.tar.gz || true
-        sudo rm -rf $KIBANA_LOG_DIR || true
         sudo rm -rf $KIBANA_CFG_DIR || true
     fi
 }
@@ -394,6 +512,8 @@ function configure_monasca_log_persister {
         sudo sed -e "
             s|%ES_SERVICE_BIND_HOST%|$ES_SERVICE_BIND_HOST|g;
         " -i $LOG_PERSISTER_DIR/persister.conf
+
+        ln -sf $LOG_PERSISTER_DIR/persister.conf $GATE_CONFIGURATION_DIR/log-persister.conf
     fi
 }
 
@@ -426,6 +546,8 @@ function configure_monasca_log_transformer {
             s|%KAFKA_SERVICE_HOST%|$KAFKA_SERVICE_HOST|g;
             s|%KAFKA_SERVICE_PORT%|$KAFKA_SERVICE_PORT|g;
         " -i $LOG_TRANSFORMER_DIR/transformer.conf
+
+        ln -sf $LOG_TRANSFORMER_DIR/transformer.conf $GATE_CONFIGURATION_DIR/log-transformer.conf
     fi
 }
 
@@ -458,6 +580,8 @@ function configure_monasca_log_metrics {
             s|%KAFKA_SERVICE_HOST%|$KAFKA_SERVICE_HOST|g;
             s|%KAFKA_SERVICE_PORT%|$KAFKA_SERVICE_PORT|g;
         " -i $LOG_METRICS_DIR/log-metrics.conf
+
+        ln -sf $LOG_METRICS_DIR/log-metrics.conf $GATE_CONFIGURATION_DIR/log-metrics.conf
     fi
 }
 
@@ -502,6 +626,8 @@ function configure_monasca_log_agent {
             s|%KEYSTONE_AUTH_URI_V3%|$KEYSTONE_AUTH_URI_V3|g;
         " -i $LOG_AGENT_DIR/agent.conf
 
+        ln -sf $LOG_AGENT_DIR/agent.conf $GATE_CONFIGURATION_DIR/log-agent.conf
+
     fi
 }
 
@@ -516,7 +642,7 @@ function start_monasca_log_agent {
     if is_service_enabled monasca-log-agent; then
         echo_summary "Starting monasca-log-agent"
         local logstash="$LOGSTASH_DIR/bin/logstash"
-        run_process "monasca-log-agent" "sudo $logstash -f $LOG_AGENT_DIR/agent.conf"
+        run_process "monasca-log-agent" "$logstash -f $LOG_AGENT_DIR/agent.conf" "root" "root"
     fi
 }
 
@@ -553,6 +679,10 @@ function clean_node_nvm {
     fi
 }
 
+function clean_gate_config_holder {
+    sudo rm -rf $GATE_CONFIGURATION_DIR || true
+}
+
 function build_kibana_plugin {
     if is_service_enabled kibana; then
         echo "Building Kibana plugin"
