@@ -13,6 +13,7 @@
 # under the License.
 
 import falcon
+from falcon import testing
 import mock
 import simplejson as json
 
@@ -23,9 +24,9 @@ from monasca_log_api.tests import base
 ENDPOINT = '/healthcheck'
 
 
-class TestApiHealthChecks(base.BaseApiTestCase):
+class TestHealthChecks(testing.TestBase):
     def before(self):
-        super(TestApiHealthChecks, self).before()
+        self.conf = base.mock_config(self)
         self.resource = healthchecks.HealthChecks()
         self.api.add_route(
             ENDPOINT,
