@@ -14,7 +14,9 @@
 # under the License.
 
 import falcon
+from falcon import testing
 import mock
+import unittest
 
 from monasca_log_api.api import exceptions as log_api_exceptions
 from monasca_log_api.api import headers
@@ -29,7 +31,7 @@ def _init_resource(test):
     return resource
 
 
-class TestLogsVersion(base.BaseApiTestCase):
+class TestLogsVersion(unittest.TestCase):
     @mock.patch('monasca_log_api.reference.common.log_publisher.LogPublisher')
     @mock.patch('monasca_log_api.reference.v2.common.service.LogCreator')
     def test_should_return_v2_as_version(self, _, __):
@@ -37,7 +39,7 @@ class TestLogsVersion(base.BaseApiTestCase):
         self.assertEqual('v2.0', logs_resource.version)
 
 
-class TestLogs(base.BaseApiTestCase):
+class TestLogs(testing.TestBase):
 
     api_class = base.MockedAPI
 
